@@ -1,14 +1,14 @@
 """
 Type annotations for dataexchange service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/literals/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/literals.html)
 
 Usage::
 
     ```python
     from mypy_boto3_dataexchange.literals import AssetTypeType
 
-    data: AssetTypeType = "REDSHIFT_DATA_SHARE"
+    data: AssetTypeType = "API_GATEWAY_API"
     ```
 """
 import sys
@@ -30,18 +30,16 @@ __all__ = (
     "ListJobsPaginatorName",
     "ListRevisionAssetsPaginatorName",
     "OriginType",
+    "ProtocolTypeType",
     "ServerSideEncryptionTypesType",
     "StateType",
     "TypeType",
-    "DataExchangeServiceName",
     "ServiceName",
-    "ResourceServiceName",
     "PaginatorName",
-    "RegionName",
 )
 
 
-AssetTypeType = Literal["REDSHIFT_DATA_SHARE", "S3_SNAPSHOT"]
+AssetTypeType = Literal["API_GATEWAY_API", "REDSHIFT_DATA_SHARE", "S3_SNAPSHOT"]
 CodeType = Literal[
     "ACCESS_DENIED_EXCEPTION",
     "INTERNAL_SERVER_EXCEPTION",
@@ -61,6 +59,7 @@ ListEventActionsPaginatorName = Literal["list_event_actions"]
 ListJobsPaginatorName = Literal["list_jobs"]
 ListRevisionAssetsPaginatorName = Literal["list_revision_assets"]
 OriginType = Literal["ENTITLED", "OWNED"]
+ProtocolTypeType = Literal["REST"]
 ServerSideEncryptionTypesType = Literal["AES256", "aws:kms"]
 StateType = Literal["CANCELLED", "COMPLETED", "ERROR", "IN_PROGRESS", "TIMED_OUT", "WAITING"]
 TypeType = Literal[
@@ -69,9 +68,9 @@ TypeType = Literal[
     "EXPORT_REVISIONS_TO_S3",
     "IMPORT_ASSETS_FROM_REDSHIFT_DATA_SHARES",
     "IMPORT_ASSETS_FROM_S3",
+    "IMPORT_ASSET_FROM_API_GATEWAY_API",
     "IMPORT_ASSET_FROM_SIGNED_URL",
 ]
-DataExchangeServiceName = Literal["dataexchange"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -85,6 +84,7 @@ ServiceName = Literal[
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -153,6 +153,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -174,6 +175,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -200,6 +202,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -258,7 +261,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -287,11 +292,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -301,6 +308,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -360,18 +368,6 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
-ResourceServiceName = Literal[
-    "cloudformation",
-    "cloudwatch",
-    "dynamodb",
-    "ec2",
-    "glacier",
-    "iam",
-    "opsworks",
-    "s3",
-    "sns",
-    "sqs",
-]
 PaginatorName = Literal[
     "list_data_set_revisions",
     "list_data_sets",
@@ -379,16 +375,3 @@ PaginatorName = Literal[
     "list_jobs",
     "list_revision_assets",
 ]
-RegionName = Literal[
-    "ap-northeast-1",
-    "ap-northeast-2",
-    "ap-southeast-1",
-    "ap-southeast-2",
-    "eu-central-1",
-    "eu-west-1",
-    "eu-west-2",
-    "us-east-1",
-    "us-east-2",
-    "us-west-1",
-    "us-west-2",
-]
