@@ -1,7 +1,7 @@
 """
 Type annotations for dataexchange service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/type_defs/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/type_defs.html)
 
 Usage::
 
@@ -15,8 +15,6 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence
 
-from typing_extensions import NotRequired
-
 from .literals import (
     AssetTypeType,
     CodeType,
@@ -28,6 +26,10 @@ from .literals import (
     TypeType,
 )
 
+if sys.version_info >= (3, 9):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -36,6 +38,7 @@ else:
 
 __all__ = (
     "ActionTypeDef",
+    "ApiGatewayApiAssetTypeDef",
     "AssetDestinationEntryTypeDef",
     "AssetDetailsTypeDef",
     "AssetEntryTypeDef",
@@ -76,6 +79,8 @@ __all__ = (
     "GetJobResponseTypeDef",
     "GetRevisionRequestRequestTypeDef",
     "GetRevisionResponseTypeDef",
+    "ImportAssetFromApiGatewayApiRequestDetailsTypeDef",
+    "ImportAssetFromApiGatewayApiResponseDetailsTypeDef",
     "ImportAssetFromSignedUrlJobErrorDetailsTypeDef",
     "ImportAssetFromSignedUrlRequestDetailsTypeDef",
     "ImportAssetFromSignedUrlResponseDetailsTypeDef",
@@ -85,19 +90,14 @@ __all__ = (
     "ImportAssetsFromS3ResponseDetailsTypeDef",
     "JobEntryTypeDef",
     "JobErrorTypeDef",
-    "ListDataSetRevisionsRequestListDataSetRevisionsPaginateTypeDef",
     "ListDataSetRevisionsRequestRequestTypeDef",
     "ListDataSetRevisionsResponseTypeDef",
-    "ListDataSetsRequestListDataSetsPaginateTypeDef",
     "ListDataSetsRequestRequestTypeDef",
     "ListDataSetsResponseTypeDef",
-    "ListEventActionsRequestListEventActionsPaginateTypeDef",
     "ListEventActionsRequestRequestTypeDef",
     "ListEventActionsResponseTypeDef",
-    "ListJobsRequestListJobsPaginateTypeDef",
     "ListJobsRequestRequestTypeDef",
     "ListJobsResponseTypeDef",
-    "ListRevisionAssetsRequestListRevisionAssetsPaginateTypeDef",
     "ListRevisionAssetsRequestRequestTypeDef",
     "ListRevisionAssetsResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
@@ -113,6 +113,8 @@ __all__ = (
     "RevisionEntryTypeDef",
     "RevisionPublishedTypeDef",
     "S3SnapshotAssetTypeDef",
+    "SendApiAssetRequestRequestTypeDef",
+    "SendApiAssetResponseTypeDef",
     "StartJobRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
@@ -134,6 +136,22 @@ ActionTypeDef = TypedDict(
     total=False,
 )
 
+ApiGatewayApiAssetTypeDef = TypedDict(
+    "ApiGatewayApiAssetTypeDef",
+    {
+        "ApiDescription": str,
+        "ApiEndpoint": str,
+        "ApiId": str,
+        "ApiKey": str,
+        "ApiName": str,
+        "ApiSpecificationDownloadUrl": str,
+        "ApiSpecificationDownloadUrlExpiresAt": datetime,
+        "ProtocolType": Literal["REST"],
+        "Stage": str,
+    },
+    total=False,
+)
+
 _RequiredAssetDestinationEntryTypeDef = TypedDict(
     "_RequiredAssetDestinationEntryTypeDef",
     {
@@ -161,6 +179,7 @@ AssetDetailsTypeDef = TypedDict(
     {
         "S3SnapshotAsset": "S3SnapshotAssetTypeDef",
         "RedshiftDataShareAsset": "RedshiftDataShareAssetTypeDef",
+        "ApiGatewayApiAsset": "ApiGatewayApiAssetTypeDef",
     },
     total=False,
 )
@@ -726,6 +745,66 @@ GetRevisionResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredImportAssetFromApiGatewayApiRequestDetailsTypeDef = TypedDict(
+    "_RequiredImportAssetFromApiGatewayApiRequestDetailsTypeDef",
+    {
+        "ApiId": str,
+        "ApiName": str,
+        "ApiSpecificationMd5Hash": str,
+        "DataSetId": str,
+        "ProtocolType": Literal["REST"],
+        "RevisionId": str,
+        "Stage": str,
+    },
+)
+_OptionalImportAssetFromApiGatewayApiRequestDetailsTypeDef = TypedDict(
+    "_OptionalImportAssetFromApiGatewayApiRequestDetailsTypeDef",
+    {
+        "ApiDescription": str,
+        "ApiKey": str,
+    },
+    total=False,
+)
+
+
+class ImportAssetFromApiGatewayApiRequestDetailsTypeDef(
+    _RequiredImportAssetFromApiGatewayApiRequestDetailsTypeDef,
+    _OptionalImportAssetFromApiGatewayApiRequestDetailsTypeDef,
+):
+    pass
+
+
+_RequiredImportAssetFromApiGatewayApiResponseDetailsTypeDef = TypedDict(
+    "_RequiredImportAssetFromApiGatewayApiResponseDetailsTypeDef",
+    {
+        "ApiId": str,
+        "ApiName": str,
+        "ApiSpecificationMd5Hash": str,
+        "ApiSpecificationUploadUrl": str,
+        "ApiSpecificationUploadUrlExpiresAt": datetime,
+        "DataSetId": str,
+        "ProtocolType": Literal["REST"],
+        "RevisionId": str,
+        "Stage": str,
+    },
+)
+_OptionalImportAssetFromApiGatewayApiResponseDetailsTypeDef = TypedDict(
+    "_OptionalImportAssetFromApiGatewayApiResponseDetailsTypeDef",
+    {
+        "ApiDescription": str,
+        "ApiKey": str,
+    },
+    total=False,
+)
+
+
+class ImportAssetFromApiGatewayApiResponseDetailsTypeDef(
+    _RequiredImportAssetFromApiGatewayApiResponseDetailsTypeDef,
+    _OptionalImportAssetFromApiGatewayApiResponseDetailsTypeDef,
+):
+    pass
+
+
 ImportAssetFromSignedUrlJobErrorDetailsTypeDef = TypedDict(
     "ImportAssetFromSignedUrlJobErrorDetailsTypeDef",
     {
@@ -854,28 +933,6 @@ class JobErrorTypeDef(_RequiredJobErrorTypeDef, _OptionalJobErrorTypeDef):
     pass
 
 
-_RequiredListDataSetRevisionsRequestListDataSetRevisionsPaginateTypeDef = TypedDict(
-    "_RequiredListDataSetRevisionsRequestListDataSetRevisionsPaginateTypeDef",
-    {
-        "DataSetId": str,
-    },
-)
-_OptionalListDataSetRevisionsRequestListDataSetRevisionsPaginateTypeDef = TypedDict(
-    "_OptionalListDataSetRevisionsRequestListDataSetRevisionsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListDataSetRevisionsRequestListDataSetRevisionsPaginateTypeDef(
-    _RequiredListDataSetRevisionsRequestListDataSetRevisionsPaginateTypeDef,
-    _OptionalListDataSetRevisionsRequestListDataSetRevisionsPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListDataSetRevisionsRequestRequestTypeDef = TypedDict(
     "_RequiredListDataSetRevisionsRequestRequestTypeDef",
     {
@@ -908,15 +965,6 @@ ListDataSetRevisionsResponseTypeDef = TypedDict(
     },
 )
 
-ListDataSetsRequestListDataSetsPaginateTypeDef = TypedDict(
-    "ListDataSetsRequestListDataSetsPaginateTypeDef",
-    {
-        "Origin": str,
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListDataSetsRequestRequestTypeDef = TypedDict(
     "ListDataSetsRequestRequestTypeDef",
     {
@@ -936,15 +984,6 @@ ListDataSetsResponseTypeDef = TypedDict(
     },
 )
 
-ListEventActionsRequestListEventActionsPaginateTypeDef = TypedDict(
-    "ListEventActionsRequestListEventActionsPaginateTypeDef",
-    {
-        "EventSourceId": str,
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListEventActionsRequestRequestTypeDef = TypedDict(
     "ListEventActionsRequestRequestTypeDef",
     {
@@ -964,16 +1003,6 @@ ListEventActionsResponseTypeDef = TypedDict(
     },
 )
 
-ListJobsRequestListJobsPaginateTypeDef = TypedDict(
-    "ListJobsRequestListJobsPaginateTypeDef",
-    {
-        "DataSetId": str,
-        "RevisionId": str,
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListJobsRequestRequestTypeDef = TypedDict(
     "ListJobsRequestRequestTypeDef",
     {
@@ -994,29 +1023,6 @@ ListJobsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListRevisionAssetsRequestListRevisionAssetsPaginateTypeDef = TypedDict(
-    "_RequiredListRevisionAssetsRequestListRevisionAssetsPaginateTypeDef",
-    {
-        "DataSetId": str,
-        "RevisionId": str,
-    },
-)
-_OptionalListRevisionAssetsRequestListRevisionAssetsPaginateTypeDef = TypedDict(
-    "_OptionalListRevisionAssetsRequestListRevisionAssetsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListRevisionAssetsRequestListRevisionAssetsPaginateTypeDef(
-    _RequiredListRevisionAssetsRequestListRevisionAssetsPaginateTypeDef,
-    _OptionalListRevisionAssetsRequestListRevisionAssetsPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListRevisionAssetsRequestRequestTypeDef = TypedDict(
     "_RequiredListRevisionAssetsRequestRequestTypeDef",
     {
@@ -1104,9 +1110,8 @@ RequestDetailsTypeDef = TypedDict(
         "ExportRevisionsToS3": "ExportRevisionsToS3RequestDetailsTypeDef",
         "ImportAssetFromSignedUrl": "ImportAssetFromSignedUrlRequestDetailsTypeDef",
         "ImportAssetsFromS3": "ImportAssetsFromS3RequestDetailsTypeDef",
-        "ImportAssetsFromRedshiftDataShares": (
-            "ImportAssetsFromRedshiftDataSharesRequestDetailsTypeDef"
-        ),
+        "ImportAssetsFromRedshiftDataShares": "ImportAssetsFromRedshiftDataSharesRequestDetailsTypeDef",
+        "ImportAssetFromApiGatewayApi": "ImportAssetFromApiGatewayApiRequestDetailsTypeDef",
     },
     total=False,
 )
@@ -1119,9 +1124,8 @@ ResponseDetailsTypeDef = TypedDict(
         "ExportRevisionsToS3": "ExportRevisionsToS3ResponseDetailsTypeDef",
         "ImportAssetFromSignedUrl": "ImportAssetFromSignedUrlResponseDetailsTypeDef",
         "ImportAssetsFromS3": "ImportAssetsFromS3ResponseDetailsTypeDef",
-        "ImportAssetsFromRedshiftDataShares": (
-            "ImportAssetsFromRedshiftDataSharesResponseDetailsTypeDef"
-        ),
+        "ImportAssetsFromRedshiftDataShares": "ImportAssetsFromRedshiftDataSharesResponseDetailsTypeDef",
+        "ImportAssetFromApiGatewayApi": "ImportAssetFromApiGatewayApiResponseDetailsTypeDef",
     },
     total=False,
 )
@@ -1198,6 +1202,42 @@ S3SnapshotAssetTypeDef = TypedDict(
     },
 )
 
+_RequiredSendApiAssetRequestRequestTypeDef = TypedDict(
+    "_RequiredSendApiAssetRequestRequestTypeDef",
+    {
+        "AssetId": str,
+        "DataSetId": str,
+        "RevisionId": str,
+    },
+)
+_OptionalSendApiAssetRequestRequestTypeDef = TypedDict(
+    "_OptionalSendApiAssetRequestRequestTypeDef",
+    {
+        "Body": str,
+        "QueryStringParameters": Mapping[str, str],
+        "RequestHeaders": Mapping[str, str],
+        "Method": str,
+        "Path": str,
+    },
+    total=False,
+)
+
+
+class SendApiAssetRequestRequestTypeDef(
+    _RequiredSendApiAssetRequestRequestTypeDef, _OptionalSendApiAssetRequestRequestTypeDef
+):
+    pass
+
+
+SendApiAssetResponseTypeDef = TypedDict(
+    "SendApiAssetResponseTypeDef",
+    {
+        "Body": str,
+        "ResponseHeaders": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 StartJobRequestRequestTypeDef = TypedDict(
     "StartJobRequestRequestTypeDef",
     {
